@@ -23,6 +23,8 @@ expression ::= old_if     action => ::first
              | unless     action => ::first
              | select     action => ::first
              | reject     action => ::first
+             | doset      action => ::first
+             | do         action => ::first
              | fix        action => ::first
 
 old_if ::= old_if_condition fixes ('end()') bless => IfElse
@@ -45,6 +47,12 @@ old_unless_condition ::= old_unless_name ('(') args (')') bless => OldCondition
 
 condition ::= name ('(') args (')') bless => Condition
 
+doset ::= ('doset') bind fixes ('end') bless => DoSet
+
+do ::= ('do') bind fixes ('end') bless => Do
+
+bind ::= name ('(') args (')') bless => Bind
+
 fix ::= name ('(') args (')') bless => Fix
 
 args ::= arg* separator => sep
@@ -162,6 +170,29 @@ sub Catmandu::Fix::Parser::OldCondition::reify {
         ->new(map { $_->reify } @$args);
 }
 
+sub Catmandu::Fix::Parser::DoSet::reify {
+    my $bind       = $_[0]->[0]->reify;
+    my $do_fixes   = $_[0]->[1];
+    $bind->return(1);
+    $bind->fixes([map { $_->reify } @$do_fixes]);
+    $bind;
+}
+
+sub Catmandu::Fix::Parser::Do::reify {
+    my $bind       = $_[0]->[0]->reify;
+    my $do_fixes   = $_[0]->[1];
+    $bind->return(0);
+    $bind->fixes([map { $_->reify } @$do_fixes]);
+    $bind;
+}
+
+sub Catmandu::Fix::Parser::Bind::reify {
+    my $name = $_[0]->[0];
+    my $args = $_[0]->[1];
+    Catmandu::Util::require_package($name, 'Catmandu::Fix::Bind')
+        ->new(map { $_->reify } @$args);
+}
+
 sub Catmandu::Fix::Parser::DoubleQuotedString::reify {
     my $str = $_[0]->[0];
 
